==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/GXModules/Gambio/CookieConsentPanel/TextPhrases/german/cookie_consent_panel.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   cookie_consent_panel.lang.inc.php 2019-12-18
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'title'                                    => 'Cookie Consent',
    'description'                              => 'Cookie-Consent-Panel anzeigen',
    'texts'                                    => 'Texte',
    'label_intro_heading'                      => 'Überschrift',
    'label_intro'                              => 'Text',
    'label_button_yes'                         => 'Label für den Zustimmen-Button',
    'label_button_yes_all'                     => 'Label für den Allen-Zustimmen-Button',
    'label_button_back'                        => 'Label für den Zurück-Button im Cookie-Preference-Center',
    'label_button_advanced_settings'           => 'Text für den Link zum Cookie-Preference-Center',
    'label_cpc_heading'                        => 'Überschrift des Cookie-Preference-Centers',
    'label_cpc_text'                           => 'Einführungstext im Cookie-Preference-Centers',
    'label_cpc_activate_all'                   => 'Label für den Button, der alle Zwecke aktiviert',
    'label_cpc_deactivate_all'                 => 'Label für den Button, der alle Zwecke deaktiviert',
    'label_cpc_purpose_desc'                   => 'Überschrift des Zwecke-Bereichs (Standard-CPC) oder Einführungstext (tabbasierter CPC)',
    'label_cpc_purpose_optout_confirm_heading' => 'Überschrift des Dialogfeldes zur Ablehnung',
    'label_cpc_purpose_optout_confirm_text'    => 'Text des Dialogfeldes zur Ablehnung',
    'label_cpc_purpose_optout_confirm_proceed' => 'Label für den Bestätigungsbutton im Ablehnungsdialogfeld',
    'label_cpc_purpose_optout_confirm_cancel'  => 'Label für den Abbrechen-Button im Ablehnungsdialogfeld',
    'label_nocookie_head'                      => 'Überschrift wenn alle Cookies nicht erlaubt sind',
    'label_nocookie_text'                      => 'Text wenn alle Cookies nicht erlaubt sind',
    'label_poi_group_list_heading'             => 'Überschrift für POI-Bereich',
    'label_poi_group_list_text'                => 'Text für POI-Bereich',
    'label_third_party'                        => 'Überschrift des Vendor-Bereichs im CPC',
    'label_cpc_purpose_01_text'                => 'Label für technische Cookies',
    'label_cpc_purpose_01_desc'                => 'Beschreibung für technische Cookies',
    'label_cpc_purpose_02_text'                => 'Label für Cookies von Zahlungsmodulen',
    'label_cpc_purpose_02_desc'                => 'Beschreibung für Cookies von Zahlungsmodulen',
    'label_cpc_purpose_03_text'                => 'Label für Tracking-Cookies',
    'label_cpc_purpose_03_desc'                => 'Beschreibung für Tracking-Cookies',
    'label_cpc_purpose_04_text'                => 'Label für Tracking-Cookies',
    'label_cpc_purpose_04_desc'                => 'Beschreibung für Tracking-Cookies',
    'label_cpc_purpose_05_text'                => 'Label für Tracking-Cookies',
    'label_cpc_purpose_05_desc'                => 'Beschreibung für Tracking-Cookies',
    'label_cpc_category_01_text'               => 'Name der ersten Zustimmungskategorie',
    'label_cpc_category_02_text'               => 'Name der zweiten Zustimmungskategorie',
    'label_cpc_category_03_text'               => 'Name der dritten Zustimmungskategorie',
    'label_cpc_category_04_text'               => 'Name der vierten Zustimmungskategorie',
    'label_cpc_category_05_text'               => 'Name der fünften Zustimmungskategorie',
    'label_cpc_category_01_desc'               => 'Beschreibung der ersten Zustimmungskategorie',
    'label_cpc_category_02_desc'               => 'Beschreibung der zweiten Zustimmungskategorie',
    'label_cpc_category_03_desc'               => 'Beschreibung der dritten Zustimmungskategorie',
    'label_cpc_category_04_desc'               => 'Beschreibung der vierten Zustimmungskategorie',
    'label_cpc_category_05_desc'               => 'Beschreibung der fünften Zustimmungskategorie',
    
    'label_cpc_categories_tab'   => 'Kategorien',
    'label_cpc_purposes_tab'     => 'Zwecke',
    'label_category'             => 'Kategorie',
    'label_category_title'       => 'Titel',
    'label_category_description' => 'Beschreibung',
    
    'label_purpose_button_create_new'  => 'Neuen Zweck hinzufügen',
    'label_purpose_modal_title_create' => 'Einen neuen Verwendungszweck erstellen',
    'label_purpose_modal_title_edit'   => 'Bearbeiten Zweck',
    'label_purpose_status'             => 'Status',
    'label_purpose_title'              => 'Titel',
    'label_purpose_description'        => 'Beschreibung',
    
    'label_cpc_button_create' => 'Erstellen',
    'label_cpc_button_save'   => 'Speichern',
    'label_cpc_button_edit'   => 'Bearbeiten',
    'label_cpc_button_update' => 'Aktualisieren',
    'label_cpc_button_delete' => 'Löschen',
    'label_cpc_button_cancel' => 'Abbrechen',
    
    'label_show_integration'           => 'Integration anzeigen',
    'integration_your_code'            => 'Ihr Javascript',
    'integration_script_path'          => 'Pfad zu Ihrem Javascript',
    'integration_your_code_headline'   => 'Integration von direkt geladenem Code',
    'integration_script_path_headline' => 'Integration von geladenen Code',

    'label_cpc_general_tab'                    => 'Allgemein',
    'label_cpc_delete_modal_title'             => 'Zweck löschen',
    'label_cpc_delete_modal_content'           => 'Bist du sicher, dass du diesen Zweck löschen möchtest?',
    'label_cpc_footer_link_text'               => 'Cookie Einstellungen',
    
    'error_message_missing_title' => 'Es muss für jede Sprache ein Titel angegeben werden.',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GXModules/Gambio/CookieConsentPanel/TextPhrases/german/cookie_consent_panel.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   cookie_consent_panel.lang.inc.php 2021-12-07
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'title'                                    => 'Cookie Consent',
    'description'                              => 'Cookie-Consent-Panel anzeigen',
    'texts'                                    => 'Texte',
    'label_intro_heading'                      => 'Überschrift',
    'label_intro'                              => 'Text',
    'label_button_yes'                         => 'Label für den Zustimmen-Button',
    'label_button_yes_all'                     => 'Label für den Allen-Zustimmen-Button',
    'label_button_only_essentials'             => 'Label für den Nur-Notwendige-Button',
    'label_button_back'                        => 'Label für den Zurück-Button im Cookie-Preference-Center',
    'label_button_advanced_settings'           => 'Text für den Link zum Cookie-Preference-Center',
    'label_cpc_heading'                        => 'Überschrift des Cookie-Preference-Centers',
    'label_cpc_text'                           => 'Einführungstext im Cookie-Preference-Centers',
    'label_cpc_activate_all'                   => 'Label für den Button, der alle Zwecke aktiviert',
    'label_cpc_deactivate_all'                 => 'Label für den Button, der alle Zwecke deaktiviert',
    'label_cpc_purpose_desc'                   => 'Überschrift des Zwecke-Bereichs (Standard-CPC) oder Einführungstext (tabbasierter CPC)',
    'label_cpc_purpose_optout_confirm_heading' => 'Überschrift des Dialogfeldes zur Ablehnung',
    'label_cpc_purpose_optout_confirm_text'    => 'Text des Dialogfeldes zur Ablehnung',
    'label_cpc_purpose_optout_confirm_proceed' => 'Label für den Bestätigungsbutton im Ablehnungsdialogfeld',
    'label_cpc_purpose_optout_confirm_cancel'  => 'Label für den Abbrechen-Button im Ablehnungsdialogfeld',
    'label_nocookie_head'                      => 'Überschrift wenn alle Cookies nicht erlaubt sind',
    'label_nocookie_text'                      => 'Text wenn alle Cookies nicht erlaubt sind',
    'label_poi_group_list_heading'             => 'Überschrift für POI-Bereich',
    'label_poi_group_list_text'                => 'Text für POI-Bereich',
    'label_third_party'                        => 'Überschrift des Vendor-Bereichs im CPC',
    'label_cpc_purpose_01_text'                => 'Label für technische Cookies',
    'label_cpc_purpose_01_desc'                => 'Beschreibung für technische Cookies',
    'label_cpc_purpose_02_text'                => 'Label für Cookies von Zahlungsmodulen',
    'label_cpc_purpose_02_desc'                => 'Beschreibung für Cookies von Zahlungsmodulen',
    'label_cpc_purpose_03_text'                => 'Label für Tracking-Cookies',
    'label_cpc_purpose_03_desc'                => 'Beschreibung für Tracking-Cookies',
    'label_cpc_purpose_04_text'                => 'Label für Tracking-Cookies',
    'label_cpc_purpose_04_desc'                => 'Beschreibung für Tracking-Cookies',
    'label_cpc_purpose_05_text'                => 'Label für Tracking-Cookies',
    'label_cpc_purpose_05_desc'                => 'Beschreibung für Tracking-Cookies',
    'label_cpc_category_01_text'               => 'Name der ersten Zustimmungskategorie',
    'label_cpc_category_02_text'               => 'Name der zweiten Zustimmungskategorie',
    'label_cpc_category_03_text'               => 'Name der dritten Zustimmungskategorie',
    'label_cpc_category_04_text'               => 'Name der vierten Zustimmungskategorie',
    'label_cpc_category_05_text'               => 'Name der fünften Zustimmungskategorie',
    'label_cpc_category_01_desc'               => 'Beschreibung der ersten Zustimmungskategorie',
    'label_cpc_category_02_desc'               => 'Beschreibung der zweiten Zustimmungskategorie',
    'label_cpc_category_03_desc'               => 'Beschreibung der dritten Zustimmungskategorie',
    'label_cpc_category_04_desc'               => 'Beschreibung der vierten Zustimmungskategorie',
    'label_cpc_category_05_desc'               => 'Beschreibung der fünften Zustimmungskategorie',
    
    'label_cpc_categories_tab'   => 'Kategorien',
    'label_cpc_purposes_tab'     => 'Zwecke',
    'label_category'             => 'Kategorie',
    'label_category_title'       => 'Titel',
    'label_category_description' => 'Beschreibung',
    
    'label_purpose_button_create_new'     => 'Neuen Zweck hinzufügen',
    'label_purpose_modal_title_create'    => 'Einen neuen Verwendungszweck erstellen',
    'label_purpose_modal_title_edit'      => 'Bearbeiten Zweck',
    'label_purpose_status'                => 'Status',
    'label_only_essentials_button_status' => '"Nur Notwendige"-Button anzeigen',
    'label_purpose_title'                 => 'Titel',
    'label_purpose_description'           => 'Beschreibung',
    
    'label_cpc_button_create' => 'Erstellen',
    'label_cpc_button_save'   => 'Speichern',
    'label_cpc_button_edit'   => 'Bearbeiten',
    'label_cpc_button_update' => 'Aktualisieren',
    'label_cpc_button_delete' => 'Löschen',
    'label_cpc_button_cancel' => 'Abbrechen',
    
    'label_show_integration'           => 'Integration anzeigen',
    'integration_your_code'            => 'Ihr Javascript',
    'integration_script_path'          => 'Pfad zu Ihrem Javascript',
    'integration_your_code_headline'   => 'Integration von direkt geladenem Code',
    'integration_script_path_headline' => 'Integration von geladenen Code',

    'label_cpc_general_tab'                    => 'Allgemein',
    'label_cpc_delete_modal_title'             => 'Zweck löschen',
    'label_cpc_delete_modal_content'           => 'Bist du sicher, dass du diesen Zweck löschen möchtest?',
    'label_cpc_footer_link_text'               => 'Cookie Einstellungen',
    
    'error_message_missing_title' => 'Es muss für jede Sprache ein Titel angegeben werden.',
];
